@@ -551,10 +551,6 @@ extern char *var_deliver_hdr;
 #define DEF_ENABLE_ORCPT	1
 extern bool var_enable_orcpt;
 
-#define VAR_ENABLE_ERRORS_TO	"enable_errors_to"
-#define DEF_ENABLE_ERRORS_TO	0
-extern bool var_enable_errors_to;
-
 #define VAR_EXP_OWN_ALIAS	"expand_owner_alias"
 #define DEF_EXP_OWN_ALIAS	0
 extern bool var_exp_own_alias;
@@ -2092,6 +2088,24 @@ extern char *var_anvil_service;
 
 #endif
 
+ /*
+  * What domain names to assume when no valid domain context exists.
+  */
+#define VAR_REM_RWR_DOMAIN		"remote_header_rewrite_domain"
+#define DEF_REM_RWR_DOMAIN		""
+extern char *var_remote_rwr_domain;
+
+#define CHECK_ADDR_MAP			"check_address_map"
+
+#define VAR_LOC_RWR_CLIENTS		"local_header_rewrite_clients"
+#ifdef USE_TLS
+#define DEF_LOC_RWR_CLIENTS		PERMIT_MYNETWORKS " " PERMIT_SASL_AUTH \
+					" " PERMIT_TLS_CLIENT
+#else
+#define DEF_LOC_RWR_CLIENTS		PERMIT_MYNETWORKS " " PERMIT_SASL_AUTH
+#endif
+extern char *var_local_rwr_clients;
+
 /* LICENSE
 /* .ad
 /* .fi
