@@ -11,11 +11,6 @@
 /* DESCRIPTION
 /* .nf
 
- /*
-  * System library.
-  */
-#include <sys/time.h>
-
  /*
   * Utility library.
   */
@@ -39,7 +34,6 @@ struct MAIL_STREAM {
     char   *class;			/* trigger class */
     char   *service;			/* trigger service */
     int     mode;			/* additional permissions */
-    struct timeval ctime;		/* creation time */
 };
 
 extern MAIL_STREAM *mail_stream_file(const char *, const char *, const char *, int);
