@@ -31,7 +31,6 @@
 /*	accordingly.
 /*
 /*	lmtp_rset() sends a lone RSET command and waits for the response.
-/*	In case of a negative reply it sets the CANT_RSET_THIS_SESSION flag.
 /*
 /*	lmtp_quit() sends a lone QUIT command and waits for the response
 /*	only if waiting for QUIT replies is enabled.
@@ -355,9 +354,6 @@ static int lmtp_loop(LMTP_STATE *state, NOCLOBBER int send_state,
 #define SENDING_MAIL \
 	(recv_state <= LMTP_STATE_DOT)
 
-#define CANT_RSET_THIS_SESSION \
-	(state->features |= LMTP_FEATURE_RSET_REJECTED)
-
     /*
      * Pipelining support requires two loops: one loop for sending and one
      * for receiving. Each loop has its own independent state. Most of the
@@ -738,8 +734,6 @@ static int lmtp_loop(LMTP_STATE *state, NOCLOBBER int send_state,
 		     * Ignore the RSET response.
 		     */
 		case LMTP_STATE_RSET:
-		    if (resp->code / 100 != 2)
-			CANT_RSET_THIS_SESSION;
 		    recv_state = LMTP_STATE_LAST;
 		    break;
 
@@ -819,11 +813,8 @@ static int lmtp_loop(LMTP_STATE *state, NOCLOBBER int send_state,
 		smtp_fputs("", 0, session->stream);
 	    if (vstream_ferror(state->src))
 		msg_fatal("queue file read error");
-	    if (rec_type != REC_TYPE_XTRA) {
-		msg_warn("%s: bad record type: %d in message content",
-			 request->queue_id, rec_type);
+	    if (rec_type != REC_TYPE_XTRA)
 		RETURN(mark_corrupt(state->src));
-	    }
 	}
 
 	/*
