@@ -15,18 +15,11 @@
 /*	The purpose is to measure client performance, not protocol
 /*	compliance.
 /*
-/*	Connections can be accepted on IPv4 or IPv6 endpoints, or on
-/*	UNIX-domain sockets.
-/*	IPv4 and IPv6 are the default.
+/*	Connections can be accepted on IPV4 endpoints or UNIX-domain sockets.
+/*	IPV4 is the default.
 /*	This program is the complement of the \fBsmtp-source\fR(1) program.
 /*
 /*	Arguments:
-/* .IP \fB-4\fR
-/*	Support IPv4 only. This option has no effect when
-/*	Postfix is built without IPv6 support.
-/* .IP \fB-6\fR
-/*	Support IPv6 only. This option is not available when
-/*	Postfix is built without IPv6 support.
 /* .IP \fB-a\fR
 /*	Do not announce SASL authentication support.
 /* .IP \fB-c\fR
@@ -77,7 +70,7 @@
 /*	Listen on the UNIX-domain socket at \fIpathname\fR.
 /* .IP \fIbacklog\fR
 /*	The maximum length the queue of pending connections,
-/*	as defined by the \fBlisten\fR(2) system call.
+/*	as defined by the listen(2) call.
 /* SEE ALSO
 /*	smtp-source(1), SMTP/LMTP message generator
 /* LICENSE
@@ -120,7 +113,6 @@
 #include <msg_vstream.h>
 #include <stringops.h>
 #include <sane_accept.h>
-#include <inet_proto.h>
 
 /* Global library. */
 
@@ -132,7 +124,7 @@ typedef struct SINK_STATE {
     VSTREAM *stream;
     VSTRING *buffer;
     int     data_state;
-    int     (*read_fn) (struct SINK_STATE *);
+    int     (*read) (struct SINK_STATE *);
     int     rcpts;
 } SINK_STATE;
 
@@ -220,7 +212,7 @@ static void data_response(SINK_STATE *state)
     state->data_state = ST_CR_LF;
     smtp_printf(state->stream, "354 End data with <CR><LF>.<CR><LF>");
     smtp_flush(state->stream);
-    state->read_fn = data_read;
+    state->read = data_read;
 }
 
 /* data_event - delayed response to DATA command */
@@ -302,7 +294,7 @@ static int data_read(SINK_STATE *state)
 	    if (msg_verbose)
 		msg_info(".");
 	    dot_response(state);
-	    state->read_fn = command_read;
+	    state->read = command_read;
 	    state->data_state = ST_ANY;
 	    break;
 	}
@@ -488,7 +480,7 @@ static int command_read(SINK_STATE *state)
 	smtp_flush(state->stream);
 	return (0);
     }
-    if (cmdp->flags & FLAG_DISCONNECT)
+    if (cmdp->flags & FLAG_DISCONNECT) 
 	return (-1);
     if (cmdp->flags & FLAG_HARD_ERR) {
 	smtp_printf(state->stream, "500 Error: command failed");
@@ -535,7 +527,7 @@ static void read_event(int unused_event, char *context)
 	    return;
 
 	case 0:
-	    if (state->read_fn(state) < 0) {
+	    if (state->read(state) < 0) {
 		if (msg_verbose)
 		    msg_info("disconnect");
 		disconnect(state);
@@ -553,7 +545,7 @@ static void disconnect(SINK_STATE *state)
     vstream_fclose(state->stream);
     vstring_free(state->buffer);
     myfree((char *) state);
-    if (max_count > 0 && counter >= max_count)
+    if (max_count > 0 && ++counter >= max_count)
 	exit(0);
 }
 
@@ -584,7 +576,7 @@ static void connect_event(int unused_event, char *context)
 	state = (SINK_STATE *) mymalloc(sizeof(*state));
 	state->stream = vstream_fdopen(fd, O_RDWR);
 	state->buffer = vstring_alloc(1024);
-	state->read_fn = command_read;
+	state->read = command_read;
 	state->data_state = ST_ANY;
 	smtp_timeout_setup(state->stream, var_tmout);
 	if (pretend_pix)
@@ -610,8 +602,6 @@ int     main(int argc, char **argv)
     int     sock;
     int     backlog;
     int     ch;
-    const char *protocols = INET_PROTO_NAME_ALL;
-    INET_PROTO_INFO *proto_info;
 
     /*
      * Initialize diagnostics.
@@ -621,14 +611,8 @@ int     main(int argc, char **argv)
     /*
      * Parse JCL.
      */
-    while ((ch = GETOPT(argc, argv, "46acCef:Fh:Ln:pPq:r:s:vw:8")) > 0) {
+    while ((ch = GETOPT(argc, argv, "acCef:Fh:Ln:pPq:r:s:vw:8")) > 0) {
 	switch (ch) {
-	case '4':
-	    protocols = INET_PROTO_NAME_IPV4;
-	    break;
-	case '6':
-	    protocols = INET_PROTO_NAME_IPV6;
-	    break;
 	case 'a':
 	    disable_saslauth = 1;
 	    break;
@@ -703,7 +687,6 @@ int     main(int argc, char **argv)
     set_cmds_flags(enable_lmtp ? "lhlo" :
 		   disable_esmtp ? "helo" :
 		   "helo, ehlo", FLAG_ENABLE);
-    proto_info = inet_proto_init("protocols", protocols);
     if (strncmp(argv[optind], "unix:", 5) == 0) {
 	sock = unix_listen(argv[optind] + 5, backlog, BLOCKING);
     } else {
