@@ -19,19 +19,8 @@ typedef struct {
     int     mask;
 } NAME_MASK;
 
-#define NAME_MASK_MATCH_REQ	(1<<0)
-#define NAME_MASK_ANY_CASE	(1<<1)
-
-#define NAME_MASK_NONE		0
-#define NAME_MASK_DEFAULT	(NAME_MASK_MATCH_REQ)
-
-#define name_mask(tag, table, str) \
-	name_mask_opt((tag), (table), (str), NAME_MASK_DEFAULT)
-#define str_name_mask(tag, table, mask) \
-	str_name_mask_opt((tag), (table), (mask), NAME_MASK_DEFAULT)
-
-extern int name_mask_opt(const char *, NAME_MASK *, const char *, int);
-extern const char *str_name_mask_opt(const char *, NAME_MASK *, int, int);
+extern int name_mask(const char *, NAME_MASK *, const char *);
+extern const char *str_name_mask(const char *, NAME_MASK *, int);
 
 /* LICENSE
 /* .ad
